@@ -6,8 +6,10 @@
 
 import os
 
-from config import supported_formats
+from zope.interface import implements
 
+from interfaces import IXSLFOConverter
+from config import supported_formats
 from html2fo import HTML2FOConverter
 from fo2xfc import (xfc_available, RTFConverter, ODTConverter, 
                     WMLConverter, DOCXConverter)
@@ -17,6 +19,8 @@ from fo2pdf import xinc_available, PDFConverter
 class Converter(object):
     """High-level OO interface to XSL-FO conversions """
 
+    implements(IXSLFOConverter)
+
     def __init__(self, filename, encoding='utf-8', cleanup=False, verbose=False):
         self.filename = filename
         self.encoding = encoding
