@@ -6,11 +6,12 @@
 
 import sys
 import tempfile
-import logging
+
 from subprocess import Popen, PIPE
+from logger import LOG
 
 win32 = (sys.platform=='win32')
-LOG = logging.getLogger()
+
 
 def newTempfile(suffix=''):
     return tempfile.mktemp(suffix=suffix)
@@ -37,6 +38,7 @@ def runcmd(cmd):
         status = p.wait()
         stdout_ = p.stdout.read().strip()
         stderr_ = p.stderr.read().strip()
+
         if stdout_:
             LOG.info(stdout_)
         if stderr_:
